<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\entities\componentEntity;

class defaultWrapper extends componentEntity
{
    public function __construct()
    {
        parent::__construct();
        //$this->setColWidth('md', 12);
    }
}
